//
//      SGXAWSParser.cpp
//
//      This source code was automatically
//      generated by SophiaFramework 4.1.1
//

#include "pself3.hpp"
#include "AWSListProducts.hpp"

// Constructor
AWSListProducts::AWSListProducts(Void) 
{
    return;
}

// Destructor
AWSListProducts::~AWSListProducts(Void)
{
	_errmsg.Clear();
	
	SFXArray<AWSProductPtr>::Enumerator enumerator = _productarray.GetFirstEnumerator();
    while (enumerator.HasNext()) 
	{
		AWSProductPtr item(enumerator.GetNext());
		delete item;
    }
    _productarray.Clear();

    return;
}

// get i-th product
AWSProductPtr AWSListProducts::GetProduct(UInt16 index)
{
	if (index < _productarray.GetSize()) {
        return _productarray[index];
    }
    return null;
}

// get list of products from favorite file

SFCError AWSListProducts::GetFavoriteProducts(SFXPathConstRef filename, SFXAnsiString producttype)
{
	SFCError error;
	UInt16 i, size;

	SFXConfig _config;
 	AWSProductPtr item;

    // Load item list from file
    error = _config.Load(filename);
	if (error != SFERR_NO_ERROR)
	{
		_errmsg = "Cannot read from file";
		return error;
	}

    // get number of items
    size = _config.ReadUInt16(0, 0);

    for (i = 0; i < size; i++) {
		//process each item
		item = AWSProduct::Factory(producttype);
		item->SetAsin(_config.ReadSFXAnsiString(i * 2 + 1, ""));
		item->SetTitle(_config.ReadSFXAnsiString(i * 2 + 2, ""));
		
		error = _productarray.Append(item);
		if (error != SFERR_NO_ERROR) break;
    }

	return error;
}

// update favorite file
Void AWSListProducts::UpdateFavoriteFile(SFXPathConstRef filename)
{
 	SFXConfig _config;
	UInt16 i;

    _config.Load(filename);
	
	// update number of favorite items 
    _config.WriteUInt16(0, (UInt16) _productarray.GetSize());

	// update product list to favorite file 
    for (i = 0; i < _productarray.GetSize(); i++) {
        _config.WriteSFXAnsiString(i * 2 + 1, _productarray[i]->GetAsin());
        _config.WriteSFXAnsiString(i * 2 + 2, _productarray[i]->GetTitle());
    }
    _config.Save();
}

// remove a product from list and delete related files
SFCError AWSListProducts::RemoveProduct(SFXAnsiStringConstRef asin)
{
    SInt16 i;
	SFCError error(SFERR_NO_ERROR);
	SFXPathConst filenameXML(DIR_NAME + asin+ ".xml");
	SFXPathConst filenameJPG(DIR_NAME + asin + ".jpg");

	for (i = 0; i < _productarray.GetSize(); i++) 
	{
		if (_productarray[i]->GetAsin() == asin) 
		{
			SFXFile::Remove(filenameXML);
			SFXFile::Remove(filenameJPG);
			delete _productarray[i];
            _productarray.Remove(i);
            
			--i;
            error = SFERR_NO_ERROR;
			break;
        }
    }
    return error;
}

// remove all products from list and delete all related files
SFCError AWSListProducts::RemoveAllProducts()
{
    SFCError error(SFERR_NO_ERROR);
	SFXPath filenameXML, filenameJPG;

	SFXArray<AWSProductPtr>::Enumerator enumerator = _productarray.GetFirstEnumerator();
	while (enumerator.HasNext()) 
	{
		AWSProductPtr item(enumerator.GetNext());
		filenameXML = SFXPath(DIR_NAME + item->GetAsin() + ".xml");
		filenameJPG = SFXPath(DIR_NAME + item->GetAsin() + ".jpg");
		SFXFile::Remove(filenameXML);
		SFXFile::Remove(filenameJPG);
        delete item;
    }
    _productarray.Clear();
	return error;
}

//Parse a XML file to get products
SFCError AWSListProducts::GetXMLProducts(SFXPathConstRef filename, SFXAnsiString producttype)
{
    SFCError error;
	SInt32 size;
	SInt32 i;

    SFXXMLDOMParser parser;
	AWSProductPtr item;

    parser.SetDoNamespaces(false);

    error = parser.Parse(filename); // parse XML file

	if (error != SFERR_NO_ERROR)
	{
		_errmsg = "Parsing failed";
		return error;
	}

    SFXXMLDocumentPtr root = parser.GetDocument(); // get the root
    
	// if parsing failed
	if (root==null)
	{
		_errmsg = "No data found";
		return SFERR_FAILED;
	}
    
	SFXXMLNodePtr _anode;

    // Get list of Items
    SFXList<SFXXMLNodePtr>* list = root->GetElementsByTagName("Item");
	
	if (list == null || list->GetSize() == 0)
	{
		_errmsg = "No item found";
		return SFERR_FAILED;
	}
    
	size = list->GetSize();

	for (i=0; i<size; i++)
	{// process each item
		_anode = list->Get(i); 
		item = AWSProduct::Factory(producttype);
		item->SetParseImageUrl(true);
        item->SetParseCustomerReviews(true);
        item->SetParseSimilarProducts(true);

		error = ParseItem(_anode, item);
		
		if (error == SFERR_NO_ERROR)
		{
			error = _productarray.Append(item);
			if (error != SFERR_NO_ERROR) break;
		}	
		
	}

	if (error != SFERR_NO_ERROR)
        _errmsg = "Parsing failed";
    
    return error;
}

SFCError AWSListProducts::GetXMLProducts(SFXXMLElementPtr root, SFXAnsiString producttype)
{
    SFCError error;
	SInt32 size;
	SInt32 i;
     
	if (root==null)
	{
		_errmsg = "No data found!";
		return SFERR_FAILED;
	}

	AWSProductPtr item;
	SFXXMLNodePtr _anode;

    // Get list of Items
    SFXList<SFXXMLNodePtr>* list = root->GetElementsByTagName("Item");
	
	if (list == null || list->GetSize() == 0)
	{
		_errmsg = "No item found!";
		return SFERR_FAILED;
	}
    
	size = list->GetSize();

	for (i=0; i<size; i++)
	{// process each item
		_anode = list->Get(i); 
		item = AWSProduct::Factory(producttype);
		item->SetParseImageUrl(true);
        item->SetParseCustomerReviews(true);
        item->SetParseSimilarProducts(true);

		error = ParseItem(_anode, item);
		
		if (error == SFERR_NO_ERROR)
		{
			error = _productarray.Append(item);
			if (error != SFERR_NO_ERROR) break;
		}	
		
	}
   
	if (error != SFERR_NO_ERROR)
		_errmsg = "Parsing failed";

    return error;
}


//Parse one item
SFCError AWSListProducts::ParseItem(SFXXMLNodePtr node, AWSProductPtr item)
{
	SFCError error(SFERR_NO_ERROR);
	
	SFXAnsiString label;
	SFXXMLNodePtr child(node);

	for (child = child->GetFirstChild(); child != null && error == SFERR_NO_ERROR; child = child->GetNextSibling())
	{
		label = SFXAnsiString(child->GetNodeName());

		if (label == "ASIN")
			item->SetAsin(item->DecodeHtml(child->GetText()));
		else if (label == "DetailPageURL")
			item->SetDetailPageURL(item->DecodeHtml(child->GetText()));
		else if (label == "SalesRank")
			item->SetSalesRank(child->GetText().Replace(',', "").AsSInt32());
		else if (label == "ItemAttributes")
		{
			if (item->IsParseItemAttributes()) 
				error = item->ParseItemAttributes(child->GetFirstChild());
			else 
				error = item->ParseTitle(child->GetFirstChild());
		}                  
		else if (label == "SmallImage")
		{
			if (item->IsParseImageUrl()) 
				error = item->ParseSmallImage(child->GetFirstChild());
		}    
		else if (label == "MediumImage")
		{
			if (item->IsParseImageUrl())
				error = item->ParseMediumImage(child->GetFirstChild());
		}
		else if (label == "LargeImage")
		{
			if (item->IsParseImageUrl())
				error = item->ParseLargeImage(child->GetFirstChild());
		}                
		else if (label == "OfferSummary")
		{
			if (item->IsParseOfferSummary())
				error = item->ParseOfferSummary(child->GetFirstChild());
		}                 
		else if (label == "Offers")
		{
			if (item->IsParseOffers())
				error = item->ParseOffers(child->GetFirstChild());
		}       
		else if (label == "CustomerReviews")
		{
			if (item->IsParseCustomerReviews())
				error = item->ParseCustomerReviews(child->GetFirstChild());
		}
		else if (label == "SimilarProducts")
		{
			if (item->IsParseSimilarProducts()) 
				error = item->ParseSimilarProducts(child->GetFirstChild());
		}
		else if (label == "BrowseNodes")
		{
			if (item->IsParseBrowserNodes()) 
				error = item->ParseBrowserNodes(child->GetFirstChild());
		}
		else if (label == "ListmaniaLists")
		{
			if (item->IsParseListmaniaLists())
				error = item->ParseListmaniaLists(child->GetFirstChild());	
		}
	}
	return error;
}


