//
//      AWSProduct.hpp
//
//      This source code was automatically
//      generated by SophiaFramework 4.1.1
//

/**
***	Project         : Amazon Products Viewing
***	File			: AWSProduct.hpp	
***	Description		: Amazon Web Service Products
**/

#ifndef __AWSPRODUCT_HPP
#define __AWSPRODUCT_HPP

#include <SophiaFramework.hpp>

// Paths to three sizes of Amazon product images for each item in the response.
// The three sizes are small, medium, and large.
SFMTYPEDEFSTRUCT(ImageUrlRec)
struct ImageUrlRec {
	SFXAnsiString	smallImageURL;
	SInt32			smallImageHeight;
	SInt32			smallImageWidth;
	SFXAnsiString	mediumImageURL;
	SInt32			mediumImageHeight;
	SInt32			mediumImageWidth;
	SFXAnsiString	largeImageURL;
	SInt32			largeImageHeight;
	SInt32			largeImageWidth;
};

// Number of offer listings and the lowest price for each of the offer listing condition classes, 
// including New, Used, Collectible, and Refurbished
SFMTYPEDEFSTRUCT(OfferSummaryRec)
struct OfferSummaryRec {
	SInt32			lowestNewPrice;
	SFXAnsiString	currencyCode;
	SFXAnsiString	formattedPrice;
	SInt32			totalNew;
	SInt32			totalUsed;
	SInt32			totalCollectible;
	SInt32			totalRefurbished;
};

// Contents of the OfferSummary response group
SFMTYPEDEFSTRUCT(OfferRec)
struct OfferRec {
	SFXAnsiString	merchantId;
	SFXAnsiString	condition;
	SFXAnsiString	offerListingId;
	SInt32			amount;
	SFXAnsiString	CurrencyCode;
	SFXAnsiString	formattedPrice;
};

// List of offers
SFMTYPEDEFSTRUCT(OffersRec)
struct OffersRec {
	SInt32 totalOffers;
	SInt32 totalOfferspages;
	SFXArray<OfferRecPtr> offers;
};

// Each customer review will contain the rating, summary, date of review, and full review text
SFMTYPEDEFSTRUCT(ReviewRec)
struct ReviewRec {
	SFXAnsiString	asin;
	SInt32			rating;
	SInt32			helpfulVotes;
	SFXAnsiString	customerId;
	SInt32			totalVotes;
	SFXDate			date;
	SFXAnsiString	summary;
	SFXAnsiString	content;
};

// List of customer reviews, an average rating (1 to 5 stars), and the total number of reviews for each item in the response
SFMTYPEDEFSTRUCT(CustomerReviewsRec)
struct CustomerReviewsRec {
	SInt32 averageRating;
	SInt32 totalReviews;
	SInt32 totalReviewPages;
	SFXArray<ReviewRecPtr> reviews;
};

// ASIN and Title of each similar product 
SFMTYPEDEFSTRUCT(SimilarProductRec)
struct SimilarProductRec {
	SFXAnsiString asin;
	SFXAnsiString title;
};

// List of similar products
SFMTYPEDEFSTRUCT(SimilarProductsRec)
struct SimilarProductsRec {
	SFXArray<SimilarProductRecPtr> similarProducts;
};

// All products listed on Amazon's websites have been classified. 
// This classification system is called browse 
SFMTYPEDEFSTRUCT(BrowserNodesRec)
struct BrowserNodesRec {
	SFXAnsiString dummy;
	// Not yet implimentation.
};

// Listmania list IDs and list names for each list returned
SFMTYPEDEFSTRUCT(ListmaniaListsRec)
struct ListmaniaListsRec {
	SFXAnsiString dummy;
	// Not yet implimentation.
};

// A common AWS(Amazon Web Services) product.
// is parent class of specific product class such as Book or DVD

SFMTYPEDEFCLASS(AWSProduct)
class AWSProduct {
SFMSEALCOPY(AWSProduct)

private:
	//to manage the XML Parsing Task
    Bool _isParseItemAttributes;
    Bool _isParseImageUrl;
    Bool _isParseOfferSummary;
    Bool _isParseOffers;
    Bool _isParseCustomerReviews;
    Bool _isParseSimilarProducts;
    Bool _isParseBrowserNodes;
    Bool _isParseListmaniaLists;

	// common attributes for all products
protected:
    SFXAnsiString	_asin;
    SFXAnsiString	_detailPageURL;
    SInt32			_salesRank;
    SFXAnsiString	_title;

    ImageUrlRecPtr			_imageUrl;
    OfferSummaryRecPtr		_offerSummary;
    OffersRecPtr			_offers;
    CustomerReviewsRecPtr	_customerReviews;
    SimilarProductsRecPtr	_similarProducts;
    BrowserNodesRecPtr		_browserNodes;
    ListmaniaListsRecPtr	_listmaniaLists;

public:
    AWSProduct();
    virtual ~AWSProduct(Void);
	static AWSProductPtr Factory(SFXAnsiString producttype);

	Void SetAsin(SFXAnsiString param) {_asin = param;}
	Void SetDetailPageURL(SFXAnsiString param) {_detailPageURL = param;}
	Void SetSalesRank(SInt32 param) {_salesRank = param;}
	Void SetTitle(SFXAnsiString param) {_title = param;}

    Void SetParseItemAttributes(Bool param) { _isParseItemAttributes = param; }
    Void SetParseImageUrl(Bool param) { _isParseImageUrl = param; }
    Void SetParseOfferSummary(Bool param) { _isParseOfferSummary = param; }
    Void SetParseOffers(Bool param) { _isParseOffers = param; }
    Void SetParseCustomerReviews(Bool param) { _isParseCustomerReviews = param; }
    Void SetParseSimilarProducts(Bool param) { _isParseSimilarProducts = param; }
    Void SetParseBrowserNodes(Bool param) { _isParseBrowserNodes = param; }
    Void SetParseListmaniaLists(Bool param) { _isParseListmaniaLists = param; }

    Bool IsParseItemAttributes(Void) { return _isParseItemAttributes; }
    Bool IsParseImageUrl(Void) { return _isParseImageUrl; }
    Bool IsParseOfferSummary(Void) { return _isParseOfferSummary; }
    Bool IsParseOffers(Void) { return _isParseOffers; }
    Bool IsParseCustomerReviews(Void) { return _isParseCustomerReviews; }
    Bool IsParseSimilarProducts(Void) { return _isParseSimilarProducts; }
    Bool IsParseBrowserNodes(Void) { return _isParseBrowserNodes; }
    Bool IsParseListmaniaLists(Void) { return _isParseListmaniaLists; }

	SFXAnsiStringConstRef GetAsin(Void) { return _asin; }
    SFXAnsiStringConstRef GetDetailPageURL(Void) { return _detailPageURL; }
    SInt32 GetSalesRank(Void) { return _salesRank; }
    SFXAnsiStringConstRef GetTitle(Void) { return _title; }

    ImageUrlRecConstPtr GetImageUrl(Void) { return _imageUrl; }
    OfferSummaryRecConstPtr GetOfferSummary(Void) { return _offerSummary; }
    OffersRecConstPtr GetOffers(Void) { return _offers; }
    CustomerReviewsRecConstPtr GetCustomerReviews(Void) { return _customerReviews; }
    SimilarProductsRecConstPtr GetSimilarProducts(Void) { return _similarProducts; }
    BrowserNodesRecConstPtr GetBrowserNodes(Void) { return _browserNodes; }
    ListmaniaListsRecConstPtr GetListmaniaLists(Void) { return _listmaniaLists; }

    virtual Void ClearData();
	SFXAnsiString DecodeHtml(SFXAnsiStringConstRef string);
    
	// parse the received XML data
	virtual	SFCError ParseItemAttributes(SFXXMLNodePtr node)=0;

	SFCError ParseTitle(SFXXMLNodePtr node);
	SFCError ParseSmallImage(SFXXMLNodePtr node);
    SFCError ParseMediumImage(SFXXMLNodePtr node);
    SFCError ParseLargeImage(SFXXMLNodePtr node);
    SFCError ParseOfferSummary(SFXXMLNodePtr node);
    SFCError ParseOffers(SFXXMLNodePtr node);
    SFCError ParseCustomerReviews(SFXXMLNodePtr node);
    SFCError ParseSimilarProducts(SFXXMLNodePtr node);
    SFCError ParseBrowserNodes(SFXXMLNodePtr node);
    SFCError ParseListmaniaLists(SFXXMLNodePtr node);

	// display product information
	virtual	SFCError MakeGeneralPane(SFRTabControlPtr tab)=0;
    virtual	SFCError MakeDetailPane(SFRTabControlPtr tab)=0;
	virtual	SFCError MakeReviewPane(SFRTabControlPtr tab);
    virtual	SFCError MakeSimilarPane(SFRTabControlPtr tab);
	virtual	SFCError MakeImagePane(SFRTabControlPtr tab);
	virtual	SFCError DisplayMe(SFXAnsiStringConstRef producttype, bool addedFavorite);
};

////AWS Book item attributes
SFMTYPEDEFSTRUCT(BookItemAttributesRec)
struct BookItemAttributesRec {
	SFXArray<SFXAnsiStringPtr> authors;
	SFXAnsiString	binding;
	SInt32			amount;
	SFXAnsiString	currencyCode;
	SFXAnsiString	formattedPrice;
	SInt32			numberOfPages;
	SInt32			packageDimensionsLength;
	SInt32			packageDimensionsWidth;
	SFXDate			publicationDate;
	SFXAnsiString	publisher;
};

//Book class, inherits from AWSProduct class
SFMTYPEDEFCLASS(AWSBook)
class AWSBook : public AWSProduct {
	SFMSEALCOPY(AWSBook)

private:
	BookItemAttributesRecPtr _itemAttributes; //Book item attributes

public:
    AWSBook(Void);
    virtual ~AWSBook(Void);

	virtual SFCError ParseItemAttributes(SFXXMLNodePtr node);

	// display book information
	virtual SFCError MakeGeneralPane(SFRTabControlPtr tab);
	virtual SFCError MakeDetailPane(SFRTabControlPtr tab);
};

//AWS DVD item attributes
SFMTYPEDEFSTRUCT(DvdItemAttributesRec)
struct DvdItemAttributesRec {
	SFXArray<SFXAnsiStringPtr> actors;
	SFXArray<SFXAnsiStringPtr> directors;
	SFXArray<SFXAnsiStringPtr> formats;
	SInt32			amount;
	SFXAnsiString	currencyCode;
	SFXAnsiString	formattedPrice;
	SFXAnsiString	publisher;
	SFXDate			releaseDate;
	SInt32			runningTime;	
};

//DVD class, inherits from AWSProduct class
SFMTYPEDEFCLASS(AWSDvd)
class AWSDvd : public AWSProduct {
	SFMSEALCOPY(AWSDvd)

private:
	DvdItemAttributesRecPtr _itemAttributes; //DVD item attributes

public:
    AWSDvd(Void);
    virtual ~AWSDvd(Void);

	virtual SFCError ParseItemAttributes(SFXXMLNodePtr node);

	// display DVD information
	virtual SFCError MakeGeneralPane(SFRTabControlPtr tab);
	virtual SFCError MakeDetailPane(SFRTabControlPtr tab);
};
#endif // __AWSPRODUCT_HPP //
