/**
***	Project         : Amazon Products Viewing
***	File			: SGRSOAPDialogSet.hpp	
***	Description		: For SOAP Communication
**/

#ifndef __SGRSOAPDIALOGSET_HPP
#define __SGRSOAPDIALOGSET_HPP

#include <SophiaFramework.hpp>
#include "SGRSoftkeyToolbox.hpp"
#include "SGRErrorDialogSet.hpp"

SFMTYPEDEFSTRUCT(SOAP_Params)
struct SOAP_Params {
	Bool _set_search_index;
	Bool _set_browse_node;
	Bool _set_keyword;
	Bool _set_asin;
	SFXAnsiString	operation;
	SFXAnsiString	search_index;
	SFXAnsiString	browse_node;
	SFXAnsiString	response_group;
	SFXAnsiString	keyword;
	SFXAnsiString	asin;
};

SFMTYPEDEFCLASS(SGRSOAPDialogSet)
class SGRSOAPDialogSet {
    SFMSEALCOPY(SGRSOAPDialogSet)
public:
    enum NotifyEnum {
        NOTIFY_CONNECT_START,
        NOTIFY_CONNECT_CANCEL,
        NOTIFY_CONNECT_END,
        NOTIFY_ERROR
    };
    typedef Void (*SOAPDialogSetSPP)(NotifyEnum, SFCError, VoidPtr);

private:
	SFXSOAPRPC			_rpc;
	SOAPDialogSetSPP	_spp;					
    VoidPtr				_reference;				// function pointer

    SFRDialogPtr		_dialog;				// standard dialog

	SOAP_ParamsPtr		_params;				// parameters
	SFXAnsiString		_ok;					// ok button label
	SFXAnsiString		_cancel;				// cancel button label
	SFXAnsiString		_text;					// dialog message
	SFXAnsiString		_title;					// dialog title
	SGRErrorDialogSet	_errorDialog;			// error dialog

	SFXXMLElementPtr    _body;					// soap body
	//SFXSOAPRPC::FAULT&	_fault;					// fault
public:
    SGRSOAPDialogSet(Void);
    virtual ~SGRSOAPDialogSet(Void);
    SFCError Open(SOAP_ParamsPtr params, Bool isConfirm, SOAPDialogSetSPP procedure, VoidPtr data, SFXAnsiStringConstRef title, SFXAnsiStringConstRef text, SFXAnsiStringConstRef ok, SFXAnsiStringConstRef cancel);
	SFXXMLElementPtrConstRef GetBody() { return _body; }

private:

    SFCError SOAPConnect(Void);
	static Void SOAP_Notify(SFCError error, const SFXSOAPRPC::Params& result, const SFXSOAPRPC::FAULT& fault, SFXSOAPParserConstRef soap, VoidPtr reference);
	Void On_SOAP_Notify(SFCError error, const SFXSOAPRPC::Params& result, const SFXSOAPRPC::FAULT& fault, SFXSOAPParserConstRef soap);
    
	HANDLER_DECLARE_VOIDDIALOG(OnDialog)
};


#endif //__SGRSOAPDIALOGSET_HPP //
