# Modified by SFMAKMODIFIER Ver 1.0
#============================================================================
#  Name:
#    $(TARGET).MAK
#
#  Description:
#    Makefile to build the $(TARGET) downloadable module.
#
#   The following nmake targets are available in this makefile:
#
#     all           - make .elf and .mod image files (default)
#     clean         - delete object directory and image files
#     filename.o    - make object file
#
#   The above targets can be made with the following command:
#
#     nmake /f $(TARGET).mak [target]
#
#  Assumptions:
#    1. The environment variable ADSHOME is set to the root directory of the
#       arm tools.
#    2. The version of ADS is 1.2 or above.
#
#  Notes:
#    None.
#
#
#        Copyright  2000-2001 QUALCOMM Incorporated.
#               All Rights Reserved.
#            QUALCOMM Proprietary/GTDR
#
#----------------------------------------------------------------------------
#============================================================================
SF_HOME        =C:\Program Files\Sophia Cradle\SophiaFramework\4.1
ARM_HOME       =$(ARMHOME)
BREW_HOME      =$(BREWDIR)
TARGET         =pself3
OBJS           =AWSListProducts.o AWSProduct.o AWSTabControl.o ListProductsWindow.o pself3.o SearchWindow.o SGRErrorDialogSet.o SGRListboxControl.o SGRSOAPDialogSet.o SGRSoftkeyToolbox.o SGRSoftkeyWindow.o 
APP_INCLUDES   = -I "$(BREWDIR)\inc" -I "$(SF_HOME)\Include"

#-------------------------------------------------------------------------------
# Target file name and type definitions
#-------------------------------------------------------------------------------

EXETYPE    = elf                # Target image file format
MODULE     = mod                # Downloadable module extension

#-------------------------------------------------------------------------------
# Target compile time symbol definitions
#
# Tells the SDK source stuffs that we're building a dynamic app.
#-------------------------------------------------------------------------------

# DYNAPP          = -DDYNAMIC_APP
DYNAPP          = -DDYNAMIC_APP


#-------------------------------------------------------------------------------
# Software tool and environment definitions
#-------------------------------------------------------------------------------

AEESRCPATH = $(BREW_HOME)\src
AEEINCPATH = $(BREW_HOME)\inc

ARMBIN = $(ARM_HOME)\bin        # ARM ADS application directory
ARMINC = $(ARM_HOME)\include    # ARM ADS include file directory
ARMLIB = $(ARM_HOME)\lib        # ARM ADS library directory

ARMCC    = $(ARMBIN)\armcc      # ARM ADS ARM 32-bit inst. set ANSI CPP compiler
ARMCPP   = $(ARMBIN)\armcpp     # ARM ADS ARM 32-bit inst. set ANSI CPP compiler
LD       = $(ARMBIN)\armlink     # ARM ADS linker
HEXTOOL  = $(ARMBIN)\fromelf     # ARM ADS utility to create hex file from image

OBJ_CMD    = -o                 # Command line option to specify output filename

#-------------------------------------------------------------------------------
# Processor architecture options
#-------------------------------------------------------------------------------

CPU = -cpu ARM7TDMI             # ARM7TDMI target processor

#-------------------------------------------------------------------------------
# ARM Procedure Call Standard (APCS) options
#-------------------------------------------------------------------------------

ROPI     = ropi                 # Read-Only(code) Position independence
INTERWRK = interwork            # Allow ARM-Thumb interworking

APCS = -apcs /$(ROPI)/$(INTERWRK)/norwpi

#-------------------------------------------------------------------------------
# Additional compile time error checking options
#-------------------------------------------------------------------------------

CHK = -fa                       # Check for data flow anomolies

#-------------------------------------------------------------------------------
# Compiler output options
#-------------------------------------------------------------------------------

OUT = -c                        # Object file output only

#-------------------------------------------------------------------------------
# Compiler/assembler debug options
#-------------------------------------------------------------------------------

# DBG = -g                        # Enable debug
DBG = -g-

#-------------------------------------------------------------------------------
# Compiler optimization options
#-------------------------------------------------------------------------------

# OPT = -Ospace -O2               # Full compiler optimization for space
OPT = -Otime -O2

#-------------------------------------------------------------------------------
# Compiler code generation options
#-------------------------------------------------------------------------------

END = -littleend                # Compile for little endian memory architecture
ZA  = -zo                       # LDR may only access 32-bit aligned addresses

CODE = $(END) $(ZA)


#-------------------------------------------------------------------------------
# Include file search path options
#-------------------------------------------------------------------------------

INC = -I. -I$(AEEINCPATH) $(APP_INCLUDES)


#-------------------------------------------------------------------------------
# Compiler pragma emulation options
#-------------------------------------------------------------------------------


#-------------------------------------------------------------------------------
# Linker options
#-------------------------------------------------------------------------------

LINK_CMD = -o                    #Command line option to specify output file
                                 #on linking

ROPILINK = -ropi                 #Link image as Read-Only Position Independent

LINK_ORDER = -first AEEMod_Load

#-------------------------------------------------------------------------------
# HEXTOOL options
#-------------------------------------------------------------------------------

BINFORMAT = -bin


#-------------------------------------------------------------------------------
# Compiler flag definitions
#-------------------------------------------------------------------------------

CFLAGS0 = $(OUT) $(DYNAPP) $(CPU) $(APCS) $(CODE) $(CHK) $(DBG)
CFLAGS  = $(CFLAGS0) $(OPT)

#-------------------------------------------------------------------------------
# Linker flag definitions
#-------------------------------------------------------------------------------

# the -entry flag is not really needed, but it keeps the linker from reporting
# warning L6305W (no entry point).  The address
# LFLAGS = $(ROPILINK) -rwpi -entry 0x8000#
LFLAGS = $(ROPILINK) -rwpi -entry AEEMod_Load#0x8000#


#----------------------------------------------------------------------------
# Default target
#----------------------------------------------------------------------------

all :  $(TARGET).$(MODULE)

#----------------------------------------------------------------------------
# Clean target
#----------------------------------------------------------------------------

# The object subdirectory, target image file, and target hex file are deleted.

clean :
	@echo ---------------------------------------------------------------
	@echo CLEAN
	-del /f $(OBJS)
	-del /f $(TARGET).$(EXETYPE)
	-del /f $(TARGET).$(MODULE)
	@echo ---------------------------------------------------------------

#============================================================================
#                           DEFAULT SUFFIX RULES
#============================================================================

# The following are the default suffix rules used to compile all objects that
# are not specifically included in one of the module specific rules defined
# in the next section.

# The following macros are used to specify the output object file, MSG_FILE
# symbol definition and input source file on the compile line in the rules
# defined below.

SRC_CPP_FILE = $(@F:.o=.cpp)      # Input source file specification
SRC_C_FILE   = $(@F:.o=.c)      # Input source file specification
OBJ_FILE = $(OBJ_CMD) $(@F)   # Output object file specification

.SUFFIXES :
.SUFFIXES : .o .dep .c .cpp

#--------------------------------------------------------------------------
# C code inference rules
#----------------------------------------------------------------------------

.cpp.o:
	@echo ---------------------------------------------------------------
	@echo OBJECT $(@F)
	$(ARMCPP) $(CFLAGS) $(INC) $(OBJ_FILE) $(SRC_CPP_FILE)
	@echo ---------------------------------------------------------------


{$(AEESRCPATH)}.c.o:
	@echo ---------------------------------------------------------------
	@echo OBJECT $(@F)
	$(ARMCC) $(CFLAGS) $(INC) $(OBJ_FILE) $(AEESRCPATH)\$(SRC_C_FILE)
	@echo ---------------------------------------------------------------


#===============================================================================
#                           MODULE SPECIFIC RULES
#===============================================================================

APP_OBJS =  $(OBJS) "$(SF_HOME)\Library\SophiaFrameworkBrew310RVCTB.a"

#----------------------------------------------------------------------------
# Lib file targets
#----------------------------------------------------------------------------

$(TARGET).$(MODULE) : $(TARGET).$(EXETYPE)
	@echo ---------------------------------------------------------------
	@echo TARGET $@
	$(HEXTOOL)  $(TARGET).$(EXETYPE) $(BINFORMAT) $(TARGET).$(MODULE)

$(TARGET).$(EXETYPE) : $(APP_OBJS)
	@echo ---------------------------------------------------------------
	@echo TARGET $@
	$(LD) $(LINK_CMD) $(TARGET).$(EXETYPE) $(LFLAGS) $(APP_OBJS) $(LINK_ORDER)

#----------------------------------------------------------------------------
# Applet Specific Rules
#----------------------------------------------------------------------------


RULE1 = .
{$(RULE1)}.c.o:
	@echo ---------------------------------------------------------------
	@echo OBJECT $(@F)
	$(ARMCC) $(CFLAGS) $(INC) $(OBJ_FILE)  $(RULE1)\$(SRC_C_FILE)
	@echo ---------------------------------------------------------------


# --------------------------------------------
# DEPENDENCY LIST, DO NOT EDIT BELOW THIS LINE
# --------------------------------------------


awslistproducts.o:	awslistproducts.cpp
awslistproducts.o:	pself3.hpp
awslistproducts.o:	pself3.bid
awslistproducts.o:	awslistproducts.hpp
awslistproducts.o:	awsproduct.hpp
awsproduct.o:	awsproduct.cpp
awsproduct.o:	pself3.hpp
awsproduct.o:	pself3.bid
awsproduct.o:	awstabcontrol.hpp
awsproduct.o:	awsproduct.hpp
awstabcontrol.o:	awstabcontrol.cpp
awstabcontrol.o:	pself3.hpp
awstabcontrol.o:	pself3.bid
awstabcontrol.o:	awstabcontrol.hpp
awstabcontrol.o:	sgrsoftkeywindow.hpp
awstabcontrol.o:	sgrsoftkeytoolbox.hpp
listproductswindow.o:	listproductswindow.cpp
listproductswindow.o:	pself3.hpp
listproductswindow.o:	pself3.bid
listproductswindow.o:	pself3_res.h
listproductswindow.o:	listproductswindow.hpp
listproductswindow.o:	sgrlistboxcontrol.hpp
listproductswindow.o:	awslistproducts.hpp
listproductswindow.o:	awsproduct.hpp
listproductswindow.o:	sgrsoapdialogset.hpp
listproductswindow.o:	sgrsoftkeytoolbox.hpp
listproductswindow.o:	sgrerrordialogset.hpp
listproductswindow.o:	sgrerrordialogset.hpp
listproductswindow.o:	sgrsoftkeywindow.hpp
listproductswindow.o:	sgrsoftkeytoolbox.hpp
pself3.o:	pself3.cpp
pself3.o:	pself3.hpp
pself3.o:	pself3.bid
pself3.o:	searchwindow.hpp
pself3.o:	sgrsoapdialogset.hpp
pself3.o:	sgrsoftkeytoolbox.hpp
pself3.o:	sgrerrordialogset.hpp
pself3.o:	awslistproducts.hpp
pself3.o:	awsproduct.hpp
pself3.o:	sgrerrordialogset.hpp
pself3.o:	sgrsoftkeywindow.hpp
pself3.o:	sgrsoftkeytoolbox.hpp
searchwindow.o:	searchwindow.cpp
searchwindow.o:	pself3.hpp
searchwindow.o:	pself3.bid
searchwindow.o:	searchwindow.hpp
searchwindow.o:	sgrsoapdialogset.hpp
searchwindow.o:	sgrsoftkeytoolbox.hpp
searchwindow.o:	sgrerrordialogset.hpp
searchwindow.o:	awslistproducts.hpp
searchwindow.o:	awsproduct.hpp
searchwindow.o:	sgrerrordialogset.hpp
searchwindow.o:	listproductswindow.hpp
searchwindow.o:	sgrlistboxcontrol.hpp
searchwindow.o:	awslistproducts.hpp
searchwindow.o:	sgrsoapdialogset.hpp
searchwindow.o:	sgrerrordialogset.hpp
searchwindow.o:	sgrsoftkeywindow.hpp
searchwindow.o:	sgrsoftkeytoolbox.hpp
sgrerrordialogset.o:	sgrerrordialogset.cpp
sgrerrordialogset.o:	sgrerrordialogset.hpp
sgrerrordialogset.o:	sgrsoftkeytoolbox.hpp
sgrlistboxcontrol.o:	sgrlistboxcontrol.cpp
sgrlistboxcontrol.o:	sgrlistboxcontrol.hpp
sgrsoapdialogset.o:	sgrsoapdialogset.cpp
sgrsoapdialogset.o:	pself3.hpp
sgrsoapdialogset.o:	pself3.bid
sgrsoapdialogset.o:	sgrsoapdialogset.hpp
sgrsoapdialogset.o:	sgrsoftkeytoolbox.hpp
sgrsoapdialogset.o:	sgrerrordialogset.hpp
sgrsoftkeytoolbox.o:	sgrsoftkeytoolbox.cpp
sgrsoftkeytoolbox.o:	sgrsoftkeytoolbox.hpp
sgrsoftkeytoolbox.o:	sgrsoftkeywindow.hpp
sgrsoftkeywindow.o:	sgrsoftkeywindow.cpp
sgrsoftkeywindow.o:	sgrsoftkeywindow.hpp
